sponsor.recode = list("D"="Dem Only","R"="Rep Only","B"="Bipartisan")
maj.recode = list("D"="D Majority","R"="R Majority")
leg.recode = list("D"="D Majority","R"="R Majority","S"="Split Majority")
agenda.recode = list("majroll"="Rolled","majblock"="Blocked","majdisappoint"="Disappointed","majsuccess"="Succeeded")
terc.recode = list('1'="Right",'0'="Moderate",'-1'="Left")

cols2 = c("blue4","red4")
cols3 = c("grey50","blue4","red4")
cols3bgr = c("blue4","grey50","red4")
cols3brg = c("blue4","red4","grey50")
cols3gbr = c("grey50","blue4","red4")

y.axis.rc.agenda = c("% of Roll Calls")
y.axis.rc = c("% Rolled of Roll Calls")
y.axis.bill = c("% Rolled of Introduced Bills")
y.axis.indiv = c("% Voted to Roll Majority")

desc_agenda_control_powers <- function() {
  graphing_data <- aj_df %>%
    rowwise() %>%
    mutate(committee_blocking = ifelse(hearing_jan == 1 | reporting_jan == 1, 1, 0),
           calendar_blocking = ifelse(majcom_jan == 1 | majleader_jan == 1, 1, 0),
           state = str_extract(chamber, "[a-zA-Z]+"),
           chamber = str_extract(chamber, "(?<=\\_)[HS]")) %>%
    left_join(data.frame(
      state = state.name,
      state_abb = state.abb
    ), ., by = "state") %>%
    mutate(partisan_control = case_when(
      state_abb %in% c("VT", "NJ", "OR", "IL", "CT", "MD", "DE", "NV",
                          "NV", "CA", "RI", "MA", "HI") ~ "Democratic-Controlled",
      state_abb %in% c("MT", "TX", "NE", "SC", "AZ", "WY", "ID", "KS", "SD",
                          "UT", "ND", "OK", "MO", "IN", "GA", "KY", "FL", "TN",
                          "WI") ~ "Republican-Controlled",
      TRUE ~ "Mixed Control")) %>%
    group_by(partisan_control) %>%
    summarize(`Committee Gatekeeping Powers` = mean(committee_blocking, na.rm = TRUE),
              `Calendar Gatekeeping Powers` = mean(calendar_blocking, na.rm = TRUE)) %>%
    pivot_longer(cols = c(`Committee Gatekeeping Powers`, `Calendar Gatekeeping Powers`), 
                 names_to = "Power", values_to = "Percent") %>%
    filter(partisan_control != "Mixed Control") 
  
  ggplot(graphing_data, aes(x=Power, y=Percent, fill=partisan_control)) + 
    geom_col(show.legend = FALSE, position = position_dodge()) + 
    scale_fill_manual(values = cols2) +
    geom_text(aes(label=scales::percent(Percent, accuracy = 0.1), y = Percent + .005),
              position=position_dodge(0.9), vjust=0) +
    scale_y_continuous(labels = scales::label_percent()) +
    labs(x=NULL, y = "Percent of Chambers Where Majority \n Party Possesses Powers") +
    theme_bw()
}

rolls_state_and_majparty <- function() {
  graphing_data <- filter(rollcalls.m, floor == 1) %>%
    group_by(st, majparty) %>% 
    summarize(roll_rate = mean(majparty.roll, na.rm = TRUE)) %>%
    group_by(st) %>%
    mutate(group = ifelse(n() == 1, paste(majparty, "Majority"), "Mixed"),
           max_rate = max(roll_rate))
  
  graphing_data$st <- reorder(as.factor(graphing_data$st), graphing_data$roll_rate)
  
  ggplot(graphing_data, aes(x = st, y = roll_rate, fill = majparty)) +
    geom_bar(stat='identity', position = "dodge") +
    geom_text(aes(y = max_rate, label = st),
              nudge_y = 0.012, size = 3) +
    facet_wrap(~group, scale = "free_y") + 
    scale_fill_manual(values = c("blue4", "red4")) +
    scale_y_continuous(breaks = c(0, 0.04, 0.08, 0.12),
                       limits = c(0, 0.15)) +
    labs(x = NULL, y = "Majority Party Roll Rate", fill = NULL) + 
    coord_flip() +
    theme_bw() +
    theme(
      axis.text.y = element_blank(),
      axis.ticks.y = element_blank(),
      legend.position = "none"
    )
}
