require(fixest)

panel_by_party <- function(power = "negative", version = "paper"){
  if(power == "negative"){
  
    roll_1d <- feols(MajRollCount ~ MedianDiff + PctMajority + 
                       MajChange + MajPartySD +
                       DividedChambers + DividedGov |
                       StateChamber + Session,
                     cluster = "StateChamber",
                     data = filter(chamber_panel, MajParty == "D"))
    
    roll_1r <- feols(MajRollCount ~ MedianDiff + PctMajority + 
                       MajChange + MajPartySD +
                       DividedChambers + DividedGov |
                       StateChamber + Session,
                     cluster = "StateChamber",
                     data = filter(chamber_panel, MajParty == "R"))
    
    block_1d <- feols(MajBlockCount ~ MedianDiff +PctMajority + 
                        MajChange + MajPartySD +
                        DividedChambers + DividedGov |
                        StateChamber + Session,
                      cluster = "StateChamber",
                      data = filter(chamber_panel, MajParty == "D"))
    
    block_1r <- feols(MajBlockCount ~ MedianDiff + PctMajority + 
                        MajChange + MajPartySD +
                        DividedChambers + DividedGov |
                        StateChamber + Session,
                      cluster = "StateChamber",
                      data = filter(chamber_panel, MajParty == "R"))
    
    if(version == "paper"){
      tab <- modelsummary(list("Rolls" = roll_1d,
                               "Rolls" = roll_1r, 
                               "Blocks" = block_1d,
                               "Blocks" = block_1r),
                          output = "gt",
                          #title = "Political Conditions and Negative Agenda Control",
                          fmt=1,
                          stars= c('*' = .05,
                                   '**' = .01,
                                   '***' = .001),
                          note = "Standard errors clustered at state level.", # *p$<$0.05; **p$<$0.01; ***p$<$0.001",
                          statistic = "({std.error})",
                          estimate  = "{estimate}{stars}",
                          coef_omit = "Intercept", 
                          gof_map = c("nobs", "adj.r.squared"), # , "r2.within.adjusted"
                          add_rows = data.frame(FE = c("Majority Party",
                                                       "Chamber FEs", "Session FEs"),
                                                model_1 = c("D", "Y", "Y"), 
                                                model_2 = c("R", "Y", "Y"),
                                                model_3 = c("D", "Y", "Y"), 
                                                model_4 = c("R", "Y", "Y")),
                          coef_map = c("MedianDiff" = "Difference in Party Medians",
                                       "MajPartySD" = "Majority Party Std Dev",
                                       "PctMinority" = "Minority Seat Share",
                                       "PctMajority" = "Majority Party Size",
                                       "MajPartyR" = "Republican Majority",
                                       "MajChange" = "Majority Party Change",
                                       "DividedChambers" = "Divided Chamber Control",
                                       "DividedGov" = "Divided Government"))
      
      tab %>% tab_header(title = "Table 4: Polarization and Negative Agenda Control")
    } else {
      tab <- modelsummary(list("Rolls (Dem. Majority)" = roll_1d,
                               "Rolls (Rep. Majority)" = roll_1r),
                          output = "gt",
                          #title = "Political Conditions and Negative Agenda Control",
                          fmt=1,
                          stars= c('*' = .05,
                                   '**' = .01,
                                   '***' = .001),
                          note = "Standard errors clustered at state level.", # *p$<$0.05; **p$<$0.01; ***p$<$0.001",
                          statistic = "({std.error})",
                          estimate  = "{estimate}{stars}",
                          coef_omit = "Intercept", 
                          gof_map = c("nobs", "adj.r.squared"), # , "r2.within.adjusted"
                          add_rows = data.frame(FE = c("Controls",
                                                       "Chamber FEs", "Session FEs"),
                                                model_1 = c("Y", "Y", "Y"), 
                                                model_2 = c("Y", "Y", "Y")),
                          coef_map = c("MedianDiff" = "Difference in Party Medians",
                                       "MajPartySD" = "Majority Party Std Dev"))
      
      tab %>% tab_style(style = cell_fill(color = 'lightblue'),
                          locations = cells_body(rows = c(1,3)))
    }
  } else {
    success_1d <- feols(MajSuccessCount ~ MedianDiff + PctMajority + 
                          MajChange + MajPartySD +
                          DividedChambers + DividedGov|
                          StateChamber + Session,
                        cluster = "StateChamber",
                        data = filter(chamber_panel, MajParty == "D"))
    
    success_1r <- feols(MajSuccessCount ~ MedianDiff +  PctMajority + 
                          MajChange + MajPartySD +
                          DividedChambers + DividedGov|
                          StateChamber + Session,
                        cluster = "StateChamber",
                        data = filter(chamber_panel, MajParty == "R"))
    
    disappoint_1d <- feols(MajDisappointCount ~ MedianDiff +  PctMajority + 
                             MajChange + MajPartySD +
                             DividedChambers + DividedGov |
                             StateChamber + Session,
                           cluster = "StateChamber",
                           data = filter(chamber_panel, MajParty == "D"))
    
    disappoint_1r <- feols(MajDisappointCount ~ MedianDiff + PctMajority + 
                             MajChange + MajPartySD +
                             DividedChambers + DividedGov |
                             StateChamber + Session,
                           cluster = "StateChamber",
                           data = filter(chamber_panel, MajParty == "R"))
    
    if(version == "paper"){
      tab <- modelsummary(list("Successes" = success_1d, 
                               "Successes" = success_1r, 
                               "Disappoints" = disappoint_1d,
                               "Disappoints" = disappoint_1r),
                          output = "gt",
                          #title = "Political Conditions and Positive Agenda Control",
                          fmt=1,
                          stars= c('*' = .05,
                                   '**' = .01,
                                   '***' = .001),
                          note = "Standard errors clustered at state level.", # *p$<$0.05; **p$<$0.01; ***p$<$0.001",
                          statistic = "({std.error})",
                          estimate  = "{estimate}{stars}",
                          coef_omit = "Intercept", 
                          gof_map = c("nobs", "adj.r.squared"), # , "r2.within.adjusted"
                          add_rows = data.frame(FE = c("Majority Party",
                                                       "Chamber FEs", "Session FEs"),
                                                model_1 = c("D", "Y", "Y"), 
                                                model_2 = c("R", "Y", "Y"),
                                                model_3 = c("D", "Y", "Y"), 
                                                model_4 = c("R", "Y", "Y")),
                          coef_map = c("MedianDiff" = "Difference in Party Medians",
                                       "MajPartySD" = "Majority Party Std Dev",
                                       "PctMinority" = "Minority Seat Share",
                                       "PctMajority" = "Majority Party Size",
                                       "MajPartyR" = "Republican Majority",
                                       "MajChange" = "Majority Party Change",
                                       "DividedChambers" = "Divided Chamber Control",
                                       "DividedGov" = "Divided Government"))
      
      tab %>% tab_header(title = "Table 5: Polarization and Positive Agenda Control")
    } else {
      tab <- modelsummary(list("Successes (Dem. Majority)" = success_1d, 
                               "Successes (Rep. Majority)" = success_1r),
                          output = "gt",
                          #title = "Political Conditions and Negative Agenda Control",
                          fmt=1,
                          stars= c('*' = .05,
                                   '**' = .01,
                                   '***' = .001),
                          note = "Standard errors clustered at state level.", # *p$<$0.05; **p$<$0.01; ***p$<$0.001",
                          statistic = "({std.error})",
                          estimate  = "{estimate}{stars}",
                          coef_omit = "Intercept", 
                          gof_map = c("nobs", "adj.r.squared"), # , "r2.within.adjusted"
                          add_rows = data.frame(FE = c("Controls",
                                                       "Chamber FEs", "Session FEs"),
                                                model_1 = c("Y", "Y", "Y"), 
                                                model_2 = c("Y", "Y", "Y")),
                          coef_map = c("MedianDiff" = "Difference in Party Medians",
                                       "MajPartySD" = "Majority Party Std Dev"))
      
      tab %>% tab_style(style = cell_fill(color = 'lightblue'),
                        locations = cells_body(rows = c(1,3)))
      
    }
  }
}
