# set up constants

sponsor.recode = list("D"="Dem Only","R"="Rep Only","B"="Bipartisan")
maj.recode = list("D"="D Majority","R"="R Majority")
leg.recode = list("D"="D Majority","R"="R Majority","S"="Split Majority")
agenda.recode = list("majroll"="Rolled","majblock"="Blocked","majdisappoint"="Disappointed","majsuccess"="Succeeded")
terc.recode = list('1'="Right",'0'="Moderate",'-1'="Left")
amount.recode = list('1'="Most",'0'="Somewhat",'-1'="Least")
terc.sponsor.recode = list('1'="Right Sponsor",'0'="Moderate Sponsor ",'-1'="Left Sponsor")

cols2 = c("blue4","red4")
cols3 = c("grey50","blue4","red4")
cols3bgr = c("blue4","grey50","red4")
cols3brg = c("blue4","red4","grey50")
cols3gbr = c("grey50","blue4","red4")

y.axis.rc.agenda = c("% of Roll Calls")
y.axis.rc = c("% Rolled of Roll Calls")
y.axis.bill = c("% Rolled of Introduced Bills")
y.axis.indiv = c("% Voted to Roll Majority")

fi <- function (filen) {
  fs::file_info(filen) %>% select(modification_time, size)
}

# Load data

load_data_code <- function (release = T) {
  # Load data
  # Load functions to create tables and figures
  if (release) {
    #source("../Code/rolls fns.R")
    source("../Code/additional funcs.R")
    source("../Code/panel funcs.R")
    
    rollcalls.m <- read_fst("../Data/rollcalls all.fst") %>% filter(type=="B")
    load("../Data/indiv-slers.Rdata")
    load("../Data/Agenda Power Panel.Rda")
    aj_df <- read.dta("../Data/Anzia and Jackman Replication Data.dta")
  } else {
    #source("../Code/Boris/rolls funcs.R")
    source("../Code/Boris/agenda descriptive funcs.R")
    source("../Code/Michael/Comparing Leviathans/additional funcs.R")
    source("../Code/Michael/Comparing Leviathans/panel funcs.R")
    
    rollcalls.m <- read_fst("../Data/Merged/rollcalls all.fst") %>% filter(type=="B")
    load("../Data/Merged/indiv-slers.Rdata")
    load("../Data/Michael/Agenda Power Panel.Rda")
    aj_df <- read.dta("../Data/Michael/Anzia and Jackman Replication Data.dta")
  }
}

desc_rolls_trend <- function (rc = T) {
  
  if (!rc) {
    summ <- bills.m %>%
      filter(year>2010) %>%
      mutate(year=as.Date(ISOdate(year, 1, 1))) %>%
      #mutate(yr=ymd(as.integer(year)),truncated=2L) %>%
      filter(!is.na(majparty.roll)) %>%
      group_by(year) %>%
      summarize(majparty.roll=mean(majparty.roll,na.rm=T),
                count = n(), 
                freq= n()/nrow(.))
    
    y.axis = y.axis.bill
  } else {
    summ <- rollcalls.m %>%
      filter(year>2010) %>%
      mutate(year=as.Date(ISOdate(year, 1, 1))) %>%
      #mutate(yr=ymd(as.integer(year)),truncated=2L) %>%
      filter(!is.na(majparty.roll)) %>%
      group_by(year) %>%
      summarize(majparty.roll=mean(majparty.roll,na.rm=T),
                count = n(), 
                freq= n()/nrow(.))
    
    y.axis = y.axis.rc
  }
  
  ggplot(data=summ, aes(x=year,y=majparty.roll)) +
    scale_x_date(date_breaks = "2 year",date_labels="%Y",limits = as.Date(c("2011-01-01","2023-01-01"))) +
    geom_line(linewidth=1, linetype = "dotted") + 
    scale_color_manual(values = cols2) +
    geom_smooth(method="lm",formula = y ~ x, se=F, color = "grey50") +
    geom_hline(yintercept = 0, linetype="dashed", color="grey50") +
    labs(x="",y=y.axis) +  
    scale_y_continuous(labels = scales::label_percent()) +
    theme_bw() + theme(legend.position = "none", legend.title = element_blank()) #+
  #facet_wrap(~majparty)
  
}

desc_rolls_trend_majparty <- function (rc=T, agenda="majroll") {
  
  #library(lubridate)
  
  summ <- rollcalls.m %>%
    filter(year>2010) %>%
    mutate(year=as.Date(ISOdate(year, 1, 1))) %>%
    #mutate(yr=ymd(as.integer(year)),truncated=2L) %>%
    filter(floor & !is.na(majparty.roll)) %>%
    mutate(majparty=recode(majparty,!!!maj.recode)) %>%
    group_by(majparty,year) %>%
    summarize(majroll=mean(majparty.roll,na.rm=T),
              majblock=mean(majparty.block,na.rm=T),
              majsuccess=mean(majparty.success,na.rm=T),
              majdisappoint=mean(majparty.disappoint,na.rm=T)) %>%
    pivot_longer(cols=c("majroll","majblock","majsuccess","majdisappoint"), values_to = "freq", values_drop_na = TRUE)
  
  if (agenda=="majroll") { summ <- summ %>% filter(name=="majroll")    }
  
  y.axis = y.axis.rc
  
  z<- summ %>%
    mutate(name = case_when(
      name == "majblock" ~ "Majority Block Rate",
      name == "majdisappoint" ~ "Majority Disappoint Rate",
      name == "majsuccess" ~ "Majority Success Rate",
      name == "majroll" ~ "Majority Roll Rate")) %>%
    ggplot(data=, aes(x=year,y=freq, color=majparty)) +
    scale_x_date(date_breaks = "2 year",date_labels="%Y",
                 limits = as.Date(c("2011-01-01","2023-01-01"))) +
    scale_color_manual(values = cols2) +
    geom_smooth(method="lm",formula = y ~ x,
                #linetype="dotted",
                se=F) +
    labs(x="",y=NULL) +  
    scale_y_continuous(labels = scales::label_percent()) +
    theme_bw() + theme(legend.position = "none", legend.title = element_blank())
  
  if (agenda!="majroll") {
    z + facet_wrap(~name,scales="free")
  } else {
    z + geom_line(linewidth=1, alpha=0.75, linetype="dotted") + facet_wrap(~majparty)
  }
  
}

desc_rolls_state_and_majparty <- function() {
  summ <- filter(rollcalls.m, floor == 1) %>%
    group_by(st, majparty) %>% 
    summarize(roll_rate = mean(majparty.roll, na.rm = TRUE)) %>%
    group_by(st) %>%
    mutate(group = ifelse(n() == 1, paste(majparty, "Majority"), "Mixed"),
           max_rate = max(roll_rate))
  
  summ$st <- reorder(as.factor(summ$st), summ$roll_rate)
  
  ggplot(summ, aes(x = st, y = roll_rate, fill = majparty)) +
    geom_bar(stat='identity', position = "dodge") +
    geom_text(aes(y = max_rate, label = st),
              nudge_y = 0.0075, size = 3) +
    facet_wrap(~group, scale = "free_y") + 
    scale_fill_manual(values = c("blue4", "red4")) +
    scale_y_continuous(#breaks = c(0, 0.25, 0.50, 0.75, 0.10),
      breaks = seq(0,.12,.04),
      #limits = c(0, 0.11),
      labels = scales::label_percent(accuracy=1)) +
    labs(x = NULL, y = "Majority Party Roll Rate", fill = NULL) + 
    coord_flip() +
    #scale_x_continuous(labels = scales::label_percent(accuracy=1)) +
    theme_bw() +
    theme(
      axis.text.y = element_blank(),
      axis.ticks.y = element_blank(),
      legend.position = "none"
    )
}

desc_rolls_maj_prof1 <- function (rc=T, output="plot", agenda="majroll", data.m=rollcalls.m) {
  
  if (rc) {
    summ <- data.m %>%
      filter(floor & !is.na(bowen1.t) & majparty %in% c("D","R")) %>%
      mutate(bowen1.t=recode(bowen1.t,!!!amount.recode),
             bowen1.t=factor(bowen1.t,levels=rev(amount.recode)),
             # sponsor.party = factor(sponsor.party,
             #                        levels = c("Dem Only", "Bipartisan", "Rep Only")),
             majparty=recode(majparty,!!!maj.recode)) %>%
      group_by(majparty,bowen1.t) %>%
      #summarize(freq=mean(majparty.roll,na.rm=T))
      summarize(majroll=mean(majparty.roll,na.rm=T),
                majblock=mean(majparty.block,na.rm=T),
                majsuccess=mean(majparty.success,na.rm=T),
                majdisappoint=mean(majparty.disappoint,na.rm=T))
    
    if (output == "table") {
      kable(summ,digits=2,col.names = c("Majority Party","Sponsor Party","Rolls","Blocks","Successes","Disappointments"),
            format.args = list(big.mark=','),caption="Search Data Summary",booktabs=TRUE)
      gt(summ, digits=2) %>% fmt_number(
        columns = num,
        decimals = 2
      )
      
    } else {
      summ <- summ %>%
        pivot_longer(cols=c("majroll","majblock","majsuccess","majdisappoint"), values_to = "freq", values_drop_na = TRUE)
      
      
      if (agenda=="majroll") { summ <- summ %>% filter(name=="majroll"); summ <- summ %>% filter(name=="majroll")     }
      
      z<- ggplot(summ,aes(x=bowen1.t, y=freq, fill=bowen1.t)) + geom_col(show.legend = FALSE) + 
        #scale_fill_manual(values = cols3bgr) +
        geom_text(aes(label=scales::percent(freq,accuracy = 0.1), y = freq + .001), position=position_dodge(0.9), vjust=0) +
        labs(x="Legislative Professionalism (Bowen and Green 2021 1D)",y=y.axis.rc) +
        scale_y_continuous(labels = scales::label_percent()) +
        theme_bw() + scale_fill_brewer(palette = "Blues")
      
      if (agenda!="majroll") {
        z + facet_wrap(~name + majparty,scales="free")
      } else {
        z + facet_wrap(~majparty)
      }
      
    }
    
    
    
  } else {
    summ <- data.m %>%
      filter(hadavote==1) %>%
      filter(!is.na(sponsor.party) & !is.na(legparty)) %>%
      mutate(sponsor.party=recode(sponsor.party,!!!sponsor.recode),
             legparty=recode(legparty,!!!leg.recode)) %>%
      group_by(legparty,sponsor.party) %>%
      summarize(freq=mean(majparty.roll,na.rm=T))
    
    ggplot(summ,aes(x=sponsor.party, y=freq, fill=sponsor.party)) + geom_col(show.legend = FALSE) + 
      scale_fill_manual(values = cols3gbr) +
      geom_text(aes(label=scales::percent(freq,accuracy = 0.1), y = freq + .001), position=position_dodge(0.9), vjust=0) +
      labs(x="Party of Bill Sponsors",y=y.axis.bill) +
      scale_y_continuous(labels = scales::label_percent()) +
      theme_bw() + facet_wrap(~legparty)
    
  }
  
  
}

model_roll_indiv_full <- function (measure="elect") {
  
  
  library(lme4)
  library(gt)
  library(modelsummary)
  
  #load("Data/Merged/indiv-slers.Rdata")
  # fi("Data/Merged/indiv-slers.Rdata")
  
  roll.indiv.elect <- list()
  
  roll.indiv.elect[["Democrats"]] <- lmer(indiv.maj.roll ~ (1 | styr) + (1 | people.id) +  
                                            margin+
                                            sponsor.t + rank.party.prop, 
                                          data = subset(slers.m.sponsor,party=="D"),
                                          control=lmerControl(optimizer = "nloptwrap"))
  roll.indiv.elect[["Republicans"]] <- lmer(indiv.maj.roll ~ (1 | styr) + (1 | people.id) +  
                                              margin+
                                              sponsor.t + rank.party.prop, 
                                            data = subset(slers.m.sponsor,party=="R"),
                                            control=lmerControl(optimizer = "nloptwrap"))
  
  if (measure != "elect") {
    roll.indiv.elect[["D Majority Pres"]] <- lmer(indiv.maj.roll ~ (1 | st) + (1 | year) + (1 | people.id) +  
                                                    pres+
                                                    sponsor.t + rank.party.prop, 
                                                  data = subset(slers.m.sponsor,party=="D"),
                                                  control=lmerControl(optimizer = "nloptwrap"))
    roll.indiv.elect[["R Majority Pres"]] <- lmer(indiv.maj.roll ~ (1 | st) + (1 | year) + (1 | people.id) +  
                                                    pres+
                                                    sponsor.t + rank.party.prop, 
                                                  data = subset(slers.m.sponsor,party=="R"),
                                                  control=lmerControl(optimizer = "nloptwrap"))
    
    rows = tribble(~term, ~`D Majority`, ~`R Majority`,~`D Majority Pres`, ~`R Majority Pres`,
                   "State-Year REs",
                   "Y", "Y","Y", "Y",
                   # "Year REs",
                   # "Y", "Y","Y", "Y",
                   "Legislator REs",
                   "Y", "Y","Y", "Y")
    
    
  } else {
    rows = tribble(~term, ~`D Majority`, ~`R Majority`,
                   "State-Year REs",
                   "Y", "Y",
                   # "Year REs",
                   # "Y", "Y",
                   "Legislator REs",
                   "Y", "Y")
    
  }
  
  modelsummary(roll.indiv.elect,output="markdown",
               metrics="RMSE",
               fmt=3,
               stars= c('*' = .05,
                        '**' = .01,
                        '***' = .001),
               note = "Standard errors displayed in parens. *p<0.05; **p<0.01; ***p<0.001",
               statistic = "({std.error})",
               estimate  = "{estimate}{stars}",
               gof_omit = "BIC|AIC|SD|ICC|RMSE|REML",
               coef_omit = "SD|Observations", 
               add_rows = rows,
               #coef_omit = "SD|Intercept", 
               coef_rename = c("margin"="Electoral Margin","pres"="Democratic Presidential Vote","rank.party.prop"="Percentile Rank within Party","(Intercept)"="Intercept",
                               "sponsor.t0"="Moderate Bill","sponsor.t1"="Conservative Bill",
                               "sponsor.maj.dist" = "Bill Distance to Majority", "gpartyR" = "Republican Governor", 
                               "prop.maj" = "Majority Party Size", "maj.sd" = "Majority Party Std Dev",
                               "sponsor.party.majminmaj" = "Majority Party Only Sponsors", "sponsor.party.majminmin" = "Minority Party Only Sponsors",
                               "health"="Health Related Bill", "polar"="Polarization Average","bowen1"="Professionalism, Bowen 1D")
  )
  
  tab <- modelsummary(roll.indiv.elect,
                      metrics="RMSE",
                      #title = "Legislator Roll Model with Election Predictors",
                      output = "gt",
                      fmt=3,
                      stars= c('*' = .05,
                               '**' = .01,
                               '***' = .001),
                      note = "Standard errors displayed in parens. *p<0.05; **p<0.01; ***p<0.001",
                      statistic = "({std.error})",
                      estimate  = "{estimate}{stars}",
                      gof_omit = "BIC|AIC|SD|ICC|RMSE|REML",
                      coef_omit = "SD|Observations", 
                      
                      add_rows = rows,
                      
                      #coef_omit = "SD|Intercept", 
                      coef_rename = c("margin"="Electoral Margin","pres"="Democratic Presidential Vote","rank.party.prop"="Percentile Rank within Party","(Intercept)"="Intercept",
                                      "sponsor.t0"="Moderate Bill","sponsor.t1"="Conservative Bill",
                                      "sponsor.maj.dist" = "Bill Distance to Majority", "gpartyR" = "Republican Governor", 
                                      "prop.maj" = "Majority Party Size", "maj.sd" = "Majority Party Std Dev",
                                      "sponsor.party.majminmaj" = "Majority Party Only Sponsors", "sponsor.party.majminmin" = "Minority Party Only Sponsors",
                                      "health"="Health Related Bill", "polar"="Polarization Average","bowen1"="Professionalism, Bowen 1D")
  )
  
  tab %>%
    # tab_style(style = cell_fill(color = 'lightblue'),
    #           locations = cells_body(rows = c(1,5,13))) %>%
    tab_options(table.align='center') %>%
    tab_header(title="Table 1: Legislator-Level Majority Roll Models")
  
  
  
}

desc_rolls_leaders <- function(data.m="rollcalls.m") {
  
  summ <- rollcalls.m %>%
    filter(floor) %>%
    mutate(majparty=recode(majparty,!!!maj.recode)) %>%
    group_by(majparty,st) %>%
    summarize(rolls=mean(majparty.roll,na.rm=T), diff=median(leader.diff,na.rm=T)) 
  
  ggplot(summ,aes(x=diff, y=rolls)) +
    #scale_fill_manual(values = cols3) +
    geom_point() +
    geom_text_repel(aes(label=st, y = rolls)) +
    labs(x="Median Distance between Leader and Maj Party Median",y=y.axis.rc) +
    scale_y_continuous(labels = scales::label_percent(accuracy=1)) +
    geom_smooth(method="lm", se=F,formula = y ~ x) +
    #ylim(0,.15) +
    theme_bw() + facet_wrap(~majparty)
  
}

desc_rolls_maj_sponsor_party <- function (rc=T, output="plot", agenda="majroll", data.m=rollcalls.m) {
  
  if (rc) {
    summ <- data.m %>%
      filter(floor & !is.na(sponsor.party) & majparty %in% c("D","R")) %>%
      mutate(sponsor.party=recode(sponsor.party,!!!sponsor.recode),
             sponsor.party = factor(sponsor.party,
                                    levels = c("Dem Only", "Bipartisan", "Rep Only")),
             majparty=recode(majparty,!!!maj.recode)) %>%
      group_by(majparty,sponsor.party) %>%
      #summarize(freq=mean(majparty.roll,na.rm=T))
      summarize(majroll=mean(majparty.roll,na.rm=T),
                majblock=mean(majparty.block,na.rm=T),
                majsuccess=mean(majparty.success,na.rm=T),
                majdisappoint=mean(majparty.disappoint,na.rm=T))
    
    if (output == "table") {
      kable(summ,digits=2,col.names = c("Majority Party","Sponsor Party","Rolls","Blocks","Successes","Disappointments"),
            format.args = list(big.mark=','),caption="Search Data Summary",booktabs=TRUE)
      gt(summ, digits=2) %>% fmt_number(
        columns = num,
        decimals = 2
      )
      
    } else {
      summ <- summ %>%
        pivot_longer(cols=c("majroll","majblock","majsuccess","majdisappoint"), values_to = "freq", values_drop_na = TRUE)
      
      if (agenda=="majroll") { summ <- summ %>% filter(name=="majroll")    }
      
      z<- ggplot(summ,aes(x=sponsor.party, y=freq, fill=sponsor.party)) + geom_col(show.legend = FALSE) + 
        scale_fill_manual(values = cols3bgr) +
        geom_text(aes(label=scales::percent(freq,accuracy = 0.1), y = freq + .001), position=position_dodge(0.9), vjust=0) +
        labs(x="Party of Bill Sponsors",y=y.axis.bill) +
        scale_y_continuous(labels = scales::label_percent()) +
        theme_bw()
      
      if (agenda!="majroll") {
        z + facet_wrap(~name + majparty,scales="free")
      } else {
        z + facet_wrap(~majparty)
      }
      
    }
    
    
    
  } else {
    summ <- data.m %>%
      filter(hadavote==1) %>%
      filter(!is.na(sponsor.party) & !is.na(legparty)) %>%
      mutate(sponsor.party=recode(sponsor.party,!!!sponsor.recode),
             legparty=recode(legparty,!!!leg.recode)) %>%
      group_by(legparty,sponsor.party) %>%
      summarize(freq=mean(majparty.roll,na.rm=T))
    
    ggplot(summ,aes(x=sponsor.party, y=freq, fill=sponsor.party)) + geom_col(show.legend = FALSE) + 
      scale_fill_manual(values = cols3gbr) +
      geom_text(aes(label=scales::percent(freq,accuracy = 0.1), y = freq + .001), position=position_dodge(0.9), vjust=0) +
      labs(x="Party of Bill Sponsors",y=y.axis.bill) +
      scale_y_continuous(labels = scales::label_percent()) +
      theme_bw() + facet_wrap(~legparty)
    
  }
  
  
  
  
}

display_models <- function (group = "all", output="paper", compact = T, path="../Objects/") {
  
  # compact=T; path="Objects/"
  library(modelsummary)
  library(gt)
  
  # tic("Model summary")
  # if (compact) {
  
  if (group == "all") {
    load(str_c(path,"floor lmer fit.Rdata"))
    reg.title = ifelse(compact,"","Multilevel Model of Majority Rolls on the Floor")
    models = "mlm.roll"
  }
  
  if (group == "cmte") {
    load(str_c(path,"committee lmer fit.Rdata"))
    reg.title = ifelse(compact,"","Multilevel Model of Majority Rolls in Committee")
    models = "mlm.roll.cmte"
  }
  
  if (group == "pre") {
    load(str_c(path,"floor pre lmer fit.Rdata"))
    reg.title = ifelse(compact,"","Multilevel Model of Majority Rolls Before Final Passage")
    models = "mlm.roll.pre"
  }
  
  if (group == "final") {
    load(str_c(path,"floor final lmer fit.Rdata"))
    reg.title = ifelse(compact,"","Multilevel Model of Majority Rolls On Final Passage")
    models = "mlm.roll.final"
  }
  
  if (group == "moderation") {
    load(str_c(path,"moderation lmer fit.Rdata"))
    reg.title = ifelse(compact,"","Multilevel Model of Bill Moderation")
    models = "mlm.roll.moderation"
  }
  
  if (output == "paper") {
    coef_map = c("sponsor.maj.dist" = "Bill Sponsor Distance to Majority", 
                 "sponsor.party.majminmin" = "Minority Party Only Sponsors", "sponsor.party.majminmaj" = "Majority Party Only Sponsors",
                 "maj.sd" = "Majority Party Std Dev","gpartyR" = "Republican Governor", 
                 "prop.maj" = "Majority Party Size", 
                 "health"="Health Related Bill", "polar"="Polarization Average",
                 "bowen1"="Professionalism, Bowen 1D","bowen2"="Professionalism, Bowen 2D")
    
  } else {
    coef_map = c("sponsor.maj.dist" = "Bill Sponsor Distance to Majority", 
                 "sponsor.party.majminmin" = "Minority Party Only Sponsors", "sponsor.party.majminmaj" = "Majority Party Only Sponsors",
                 #"maj.sd" = "Majority Party Std Dev",
                 "gpartyR" = "Republican Governor")
  }
  
  if (group == "pre_and_final") {
    #tic("Load models")
    load(str_c(path,"floor pre lmer fit.Rdata"))
    load(str_c(path,"floor final lmer fit.Rdata"))
    #toc()
    #fi(str_c(path,"floor pre lmer fit.Rdata"))
    #fi(str_c(path,"floor final lmer fit.Rdata"))
    reg.title = ifelse(compact,"","Multilevel Model of Majority Rolls on the Floor")
    models.both = c(mlm.roll.final,mlm.roll.pre)
    models = "models.both"
    
    ran_effects = tribble(~term, ~`D Majority`, ~`E Majority`,~`D2 Majority`,~`E2 Majority`,                       "State-Year REs",
                          "Y", "Y","Y", "Y",
                          "Bill REs",
                          "Y", "Y","Y","Y")
    
  } else {
    ran_effects = tribble(~term, ~`D Majority`, ~`E Majority`,
                          "State-Year REs",
                          "Y", "Y",
                          "Bill REs",
                          "Y", "Y")
    
  }
  
  tab <- modelsummary(get(models),
                      title = reg.title,
                      output = "gt",
                      metrics="RMSE",
                      fmt=3,
                      stars= c('*' = .05,
                               '**' = .01,
                               '***' = .001),
                      note = "Standard errors displayed in parens. *p<0.05; **p<0.01; ***p<0.001",
                      statistic = "({std.error})",
                      estimate  = "{estimate}{stars}",
                      gof_omit = "BIC|AIC|SD|ICC|RMSE|REML",
                      add_rows = ran_effects,
                      
                      # add_rows = tribble(~term, ~`D Majority`, ~`E Majority`,
                      #                    "State REs", 
                      #                    "Y", "Y", 
                      #                    "Bill REs", 
                      #                    "Y", "Y"), 
                      coef_omit = "SD|Intercept", 
                      coef_map = coef_map)
  
  if (group %in% c("pre_and_final")) {
    tab <- tab %>%
      tab_spanner(label='Final Passage',columns=c(2:3)) %>%
      tab_spanner(label='Earlier Votes',columns=c(4:5)) %>%
      tab_style(style = cell_fill(color = 'lightblue'),
                locations = cells_body(rows = c(1,3)))
    if (output=="paper") {
      tab %>% tab_header(title="", subtitle="Table 2: Regression Analysis of Majority Party Rolls, All Floor Votes")
    } else {
      tab
    }
  } else if (group %in% c("all")) {
    tab %>%
      tab_options(table.align='center') %>%
      tab_header(title="Table 2: Bill Characteristics and Majority Party Rolls")
  } else {
    if (group %in% "moderation") {
      tab 
    } else {
      tab %>%
        tab_style(style = cell_fill(color = 'lightblue'),
                  locations = cells_body(rows = c(1,5,11))) %>%
        tab_options(table.align='center') %>%
        tab_header(title="", subtitle="Table 3: Regression Analysis of Majority Party Rolls, Committee Votes")
    }
    
  }
  
}

marginal_fx_floor_spatial <- function (path="../Objects/",group) {
  library(ggeffects)
  library(cowplot)
  library(ggplot2)
  
  #path="Objects/"
  
  # for (i in c("pre","final")) {
  
  if (group == "pre") {
    load(str_c(path,"floor pre lmer fit.Rdata"))
    out.d<-ggpredict(mlm.roll.pre[["D Majority"]],terms="sponsor.maj.dist[-2,-1,0,1,2]", condition = c(sponsor.party.majmin="min"))
    out.r<-ggpredict(mlm.roll.pre[["R Majority"]],terms="sponsor.maj.dist[-2,-1,0,1,2]", condition = c(sponsor.party.majmin="min"))
  }
  
  if (group == "final") {
    load(str_c(path,"floor final lmer fit.Rdata"))
    out.d<-ggpredict(mlm.roll.final[["D Majority"]],terms="sponsor.maj.dist[-2,-1,0,1,2]", condition = c(sponsor.party.majmin="min"))
    out.r<-ggpredict(mlm.roll.final[["R Majority"]],terms="sponsor.maj.dist[-2,-1,0,1,2]", condition = c(sponsor.party.majmin="min"))
  }
  
  if (group == "all") {
    load(str_c(path,"floor lmer fit.Rdata"))
    out.d<-ggpredict(mlm.roll[["D Majority"]],terms="sponsor.maj.dist[-2,-1,0,1,2]", condition = c(sponsor.party.majmin="min"))
    out.r<-ggpredict(mlm.roll[["R Majority"]],terms="sponsor.maj.dist[-2,-1,0,1,2]", condition = c(sponsor.party.majmin="min"))
  }
  
  low.r = tail(out.r$conf.low,1)
  hi.r = head(out.r$conf.high,1)
  
  plot.d <- plot(out.d) + 
    labs(x="Bill Sponsor Distance to Majority Median", y="% Rolled", title="Democratic Majority") +
    scale_x_continuous(limits = c(-2, 2)) +
    scale_y_continuous(limits = c(low.r,hi.r), labels = scales::label_percent(accuracy=1))
  plot.r <- plot(out.r) + 
    labs(x="Bill Sponsor Distance to Majority Median", y=NULL, title="Republican Majority") +
    scale_x_continuous(limits = c(-2, 2)) +
    scale_y_continuous(limits = c(low.r,hi.r), labels = scales::label_percent(accuracy=1))
  
  
  plot_grid(plot.d, plot.r, 
            rel_widths = c(1, 1),
            nrow = 1)
  
}

desc_rolls_policy <- function (rc=T) {
  
  
  if (rc) {
    
    policy <- rollcalls.m %>%
      select(floor,type,majparty,majparty.roll,contains("g.")) %>%
      select(-g.military)%>%
      pivot_longer(cols=contains("g."), values_drop_na = TRUE) %>%
      filter(!value==0) %>%
      mutate(name=str_remove(name,"^g\\."))
    
    policy
    
    summ <- policy %>%
      filter(floor) %>%
      filter(type=="B") %>%
      filter(!is.na(majparty.roll))%>%
      mutate(majparty=recode(majparty,!!!maj.recode)) %>%
      group_by(majparty,name) %>%
      summarize(freq=mean(majparty.roll,na.rm=T)) %>%
      ungroup() %>%
      mutate(majparty = factor(majparty, levels = c("R Majority", "D Majority"), ordered = TRUE),
             name = reorder(as.factor(name), freq))
    
    summ
    
    ggplot(summ,aes(x=name, y=freq, fill=name)) + geom_col(show.legend = FALSE) + 
      #scale_fill_manual(values = c("grey20","grey50")) +
      geom_text(aes(label=scales::percent(freq,accuracy = 0.1), y = freq + .005), size=3) +
      # scale_fill_brewer(palette = "Dark2") +
      labs(x="Policy Area",y=y.axis.rc) +
      scale_y_continuous(labels = scales::label_percent()) +
      coord_flip() + 
      facet_wrap(~majparty) + theme_bw()
    
  } else {
    
    ### not coded -- don't use
    
    summ <- bills.m %>%
      filter(hadavote==1) %>%
      mutate(sponsor.party=recode(sponsor.party,!!!sponsor.recode),
             legparty=recode(legparty,!!!leg.recode)) %>%
      group_by(legparty,sponsor.party) %>%
      summarize(freq=mean(majparty.roll,na.rm=T))
    
    ggplot(summ,aes(x=sponsor.party, y=freq, fill=sponsor.party)) + geom_col(show.legend = FALSE) + 
      scale_fill_manual(values = cols3) +
      geom_text(aes(label=scales::percent(freq,accuracy = 0.1), y = freq + .001), position=position_dodge(0.9), vjust=0) +
      labs(x="Party of Bill Sponsors",y=y.axis.bill) +
      scale_y_continuous(labels = scales::label_percent()) +
      theme_bw() + facet_wrap(~legparty)
    
  }
  
  
}

desc_rolls_trend_majparty <- function (rc=T, agenda="majroll") {
  
  #library(lubridate)
  
  summ <- rollcalls.m %>%
    filter(year>2010) %>%
    mutate(year=as.Date(ISOdate(year, 1, 1))) %>%
    #mutate(yr=ymd(as.integer(year)),truncated=2L) %>%
    filter(floor & !is.na(majparty.roll)) %>%
    mutate(majparty=recode(majparty,!!!maj.recode)) %>%
    group_by(majparty,year) %>%
    summarize(majroll=mean(majparty.roll,na.rm=T),
              majblock=mean(majparty.block,na.rm=T),
              majsuccess=mean(majparty.success,na.rm=T),
              majdisappoint=mean(majparty.disappoint,na.rm=T)) %>%
    pivot_longer(cols=c("majroll","majblock","majsuccess","majdisappoint"), values_to = "freq", values_drop_na = TRUE)
  
  if (agenda=="majroll") { summ <- summ %>% filter(name=="majroll")    }
  
  y.axis = y.axis.rc
  
  z<- summ %>%
    mutate(name = case_when(
      name == "majblock" ~ "Majority Block Rate",
      name == "majdisappoint" ~ "Majority Disappoint Rate",
      name == "majsuccess" ~ "Majority Success Rate",
      name == "majroll" ~ "Majority Roll Rate")) %>%
    ggplot(data=, aes(x=year,y=freq, color=majparty)) +
    scale_x_date(date_breaks = "2 year",date_labels="%Y",
                 limits = as.Date(c("2011-01-01","2023-01-01"))) +
    scale_color_manual(values = cols2) +
    geom_smooth(method="lm",formula = y ~ x,
                #linetype="dotted",
                se=F) +
    labs(x="",y=NULL) +  
    scale_y_continuous(labels = scales::label_percent()) +
    theme_bw() + theme(legend.position = "none", legend.title = element_blank())
  
  if (agenda!="majroll") {
    z + facet_wrap(~name,scales="free")
  } else {
    z + geom_line(linewidth=1, alpha=0.75, linetype="dotted") + facet_wrap(~majparty)
  }
  
}

desc_polar_and_hetero <- function(){
  summ <- rollcalls.m %>%
    filter(floor) %>%
    filter(type=="B") %>%
    mutate(majparty=recode(majparty,!!!maj.recode)) %>%
    group_by(majparty,st) %>%
    summarize(rolls=mean(majparty.roll,na.rm=T), 
              polar=mean(polar,na.rm=T),
              maj.sd=mean(maj.sd,na.rm=T)
    ) %>%
    filter(rolls!=0) # %>%
  # pivot_longer(cols = c(polar, maj.sd),
  #              names_to = "type",
  #              values_to = "polarization")
  
  polar_plot <- ggplot(summ,aes(x=polar, y=rolls)) +
    #scale_fill_manual(values = cols3) +
    geom_point() +
    geom_text_repel(aes(label=st, y = rolls)) +
    labs(x="Average Distance Between Medians", y="% Rolled of Roll Calls") +
    scale_y_continuous(labels = scales::label_percent(accuracy=1)) +
    geom_smooth(method="lm", se=F,formula = y ~ x) +
    facet_wrap(~majparty) +
    #ylim(0,.15) +
    theme_bw()
  
  hetero_plot <- ggplot(summ,aes(x=maj.sd, y=rolls)) +
    #scale_fill_manual(values = cols3) +
    geom_point() +
    geom_text_repel(aes(label=st, y = rolls)) +
    labs(x="Average Majority Party Heterogeneity",y="% Rolled of Roll Calls") +
    scale_y_continuous(labels = scales::label_percent(accuracy=1)) +
    geom_smooth(method="lm", se=F,formula = y ~ x) +
    facet_wrap(~majparty) +
    #ylim(0,.15) +
    theme_bw()
  
  plot_grid(polar_plot, hetero_plot, nrow = 2)
}
